@@ -5,7 +5,6 @@ import struct
 from dataclasses import dataclass
 from enum import Enum
 from multipledispatch import dispatch
-from PyQt5.QtCore import pyqtSlot
 
 @dataclass
 class systemSTAT:
@@ -152,7 +151,7 @@ moveCmdFlag = False
 moveCmdCnt = 0
 cmd_send_flag = 0  # read cmd에서 사용하기 위한 flag
 
-__RB_VERSION__ = 'a-0.1'
+__RB_VERSION__ = '0.0.3'
 
 
 def ConnectToCB(ip):
@@ -170,11 +169,8 @@ def ConnectToCB(ip):
     global data_connect
     cmd_connect = CMDSock.connect_ex((ip, CMD_PORT))
     data_connect = DATASock.connect_ex((ip, DATA_PORT))
-    print('bcd')
+    
     if cmd_connect == 0 & data_connect == 0:
-        # msg = 'set_speed_bar(0.0)'
-        # CMDSock.send(msg.encode('utf-8'))
-        print('abc')
 
         DATAREQ_THREAD = threading.Thread(target=ReqDataStart, args=(DATASock,))
         CMDREAD_THREAD = threading.Thread(target=ReadCMD, args=(CMDSock,))
@@ -186,12 +182,6 @@ def ConnectToCB(ip):
         # pass
         return True
 
-        # msg = 'set_speed_bar(1.0)'
-        # CMDSock.send(msg.encode('utf-8'))
-        # msg_recv = CMDSock.recv(4000)
-        # if msg_recv[0] == 0x54:
-        #     print(msg_recv)
-
 
 def DisConnectToCB():
     global cmd_connect
